@@ -6,13 +6,14 @@ use warnings;
 use Mojo::JSON qw(encode_json decode_json);
 use Mojo::Base 'Mojolicious::Controller';
 use Mojo::Promise;
+use Storable qw(dclone);
 
 use Encode;
 
 
 has toUTF8 => sub { find_encoding('utf8') };
 
-our $VERSION = '1.0.3';
+our $VERSION = '1.0.4';
 
 has 'service';
 
@@ -135,7 +136,7 @@ sub dispatch {
              message => "method $method does not exist.", 
              code=> 4
         } if not $self->can($method);
-        $self->logRpcCall($method,$self->rpcParams);
+        $self->logRpcCall($method,dclone($self->rpcParams));
         
             
         }
@@ -187,7 +188,7 @@ sub renderJsonRpcResult {
 	my $self = shift;
 	my $data = shift;
     my $reply = { id => $self->requestId, result => $data };
-    $self->logRpcReturn($reply);
+    $self->logRpcReturn(dclone($reply));
     $self->finalizeJsonRpcReply(encode_json($reply);
 }
 
